@@ -653,114 +653,3 @@ class GP(object):
         ax.plot(X, mean, lw=2, color=color)
         ax.plot(x, y, 'o', ms=7, color=markercolor)
         ax.set_xlim(*xlim)
-
-    def fit_MLII(self, params_to_fit, randf=None, nrestart=5, verbose=False):
-        """
-        Fit parameters of the gaussian process using MLII (maximum
-        likelihood) estimation.
-
-        Note that this method modifies the gaussian process in
-        place. After the method is run, the `GP` object will have new
-        parameters set to the best ones found during the optimization.
-
-        The optimization algorithm used is L-BFGS-B.
-
-        Parameters
-        ----------
-        params_to_fit : boolean array_like
-            A list of booleans corresponding to the gaussian process
-            parameters, indicating which parameters should be
-            fit. Parameters which are not fit keep their current value.
-
-        randf : list of functions (optional)
-            A list of functions to give an initial starting value for
-            each parameter that is being fit. The functions should
-            take no arguments, and return a numpy.float64. If not
-            specified, the functions default to ``lambda:
-            abs(numpy.random.normal())``.
-
-        nrestart : int (optional)
-            Number of random restarts to use. The best parameters out of
-            all the random restarts are used.
-
-        verbose : bool (optional)
-            Whether to print information about the optimization.
-
-        """
-
-        # original parameter list
-        params = list(self.params)
-        # boolean array of which parameters to fit
-        fitmask = np.array(params_to_fit, dtype='bool')
-
-        # default for randf
-        if randf is None:
-            randf = tuple(
-                lambda: np.abs(np.random.normal())
-                for p in params_to_fit if p)
-
-        # figure out the indices of the params we are fitting
-        j = 0
-        iparam = []
-        for i in xrange(len(params)):
-            if params_to_fit[i]:
-                iparam.append(j)
-                j += 1
-            else:
-                iparam.append(None)
-
-        # update the GP object with new parameter values
-        def new_params(theta):
-            out = [params[i] if j is None else theta[j]
-                   for i, j in enumerate(iparam)]
-            return out
-
-        # negative log likelihood
-        def f(theta):
-            params = new_params(theta)
-            try:
-                self.params = params
-            except ValueError:
-                out = np.inf
-            else:
-                out = -self.log_lh
-            return out
-
-        # jacobian of the negative log likelihood
-        def df(theta):
-            params = new_params(theta)
-            try:
-                self.params = params
-            except ValueError:
-                out = np.empty(len(theta))
-                out.fill(np.inf)
-            else:
-                out = -self.dloglh_dtheta[fitmask]
-            return out
-
-        # run the optimization a few times to find the best fit
-        args = np.empty((nrestart, len(randf)))
-        fval = np.empty(nrestart)
-        for i in xrange(nrestart):
-            p0_i = tuple(r() for r in randf)
-            self.params = new_params(p0_i)
-            logger.debug("p0 = %s", p0_i)
-            popt = optim.minimize(
-                fun=f, x0=p0_i, jac=df, method='L-BFGS-B',
-                options={'disp': verbose})
-
-            args[i] = popt['x']
-            fval[i] = popt['fun']
-
-            logger.debug("-MLL(%s) = %f", args[i], fval[i])
-            if not popt['success'] or np.isinf(fval[i]):
-                logger.warning("MLII failed, p=%s" % args[i])
-                fval[i] = np.nan
-
-        # choose the parameters that give the best MLL
-        if np.isnan(fval).all():
-            raise RuntimeError("Could not find MLII parameter estimates")
-
-        # update our parameters
-        self.params = new_params(args[np.nanargmin(fval)])
-        logger.info("Best parameters: %s", self.params)
