@@ -348,55 +348,3 @@ def test_plot():
     gp.plot(xlim=[0, 1])
 
     plt.close('all')
-
-
-def test_fit_MLII():
-    gp = make_gp()
-    gp.fit_MLII([True, False, False])
-    gp.fit_MLII([False, True, False])
-    gp.fit_MLII([False, False, True])
-    gp.fit_MLII([True, True, False])
-    gp.fit_MLII([True, True, True])
-
-    f = lambda: np.abs(np.random.normal())
-    gp.fit_MLII([True, False, False], randf=(f,))
-    gp.fit_MLII([False, True, False], randf=(f,))
-    gp.fit_MLII([False, False, True], randf=(f,))
-    gp.fit_MLII([True, True, False], randf=(f, f))
-    gp.fit_MLII([True, True, True], randf=(f, f, f))
-
-    x = np.array([0.0, 0.3490658503988659, 0.6981317007977318,
-                  1.0471975511965976, 1.3962634015954636, 1.7453292519943295,
-                  2.0943951023931953, 0.41968261, 0.97349106, 1.51630532,
-                  1.77356282, 2.07011378, 2.87018553, 3.70955074, 3.96680824,
-                  4.50962249, 4.80617345, 5.06343095, 5.6062452])
-
-    y = np.array([-5.297411814764175e-16, 2.2887507861169e-16,
-                  1.1824308893126911e-15, 1.9743321560961036e-15,
-                  3.387047586844716e-15, 3.2612801348363973e-15,
-                  2.248201624865942e-15, -3.061735126365188e-05,
-                  2.1539042816804896e-05, -3.900581031467468e-05,
-                  4.603140942399664e-05, 0.00014852070373963522,
-                  -0.011659908151004955, -0.001060998167383152,
-                  -0.0002808538329216448, -8.057870658869265e-06,
-                  -7.668984947838558e-07, -7.910215881378919e-08,
-                  -3.2649468298271893e-10])
-
-    h, w = (0.53356762300842819, 2.1479780263878867)
-    gp = GP(kernel(h, w), x, y, s=0)
-    fh = lambda: h
-    fw = lambda: w
-    with pytest.raises(RuntimeError):
-        gp.fit_MLII([True, True, False], randf=(fh, fw), nrestart=1)
-
-
-@pytest.mark.xfail
-def test_fit_same():
-    params = None
-    for i in xrange(10):
-        gp = make_gp()
-        seed()
-        gp.fit_MLII([True, True, False])
-        if params is None:
-            params = gp.params.copy()
-        assert (params == gp.params).all()
